summaryrefslogtreecommitdiffstats
path: root/lib/MiddleWare/PluginManager.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/MiddleWare/PluginManager.h')
-rw-r--r--lib/MiddleWare/PluginManager.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/MiddleWare/PluginManager.h b/lib/MiddleWare/PluginManager.h
index 574c9ff7..4883a107 100644
--- a/lib/MiddleWare/PluginManager.h
+++ b/lib/MiddleWare/PluginManager.h
@@ -132,12 +132,12 @@ class CPluginManager
*/
plugin_type_t GetPluginType(const std::string& pName);
/**
* A method, which gets all needed plugin info. It can be send via DBus
* to GUI and displayed to an user.
* @param pName A Name of plugin.
* @return A map <key, vaule>
*/
- map_string_string_t GetPluginInfo(const std::string& pName);
+ vector_map_string_string_t GetPluginsInfo();
};
#endif /*PLUGINMANAGER_H_*/
@@ -132,12 +132,12 @@ class CPluginManager
plugin_type_t GetPluginType(const std::string& pName);
/**
- * A method, which gets all needed plugin info. It can be send via DBus
- * to GUI and displayed to an user.
- * @param pName A Name of plugin.
- * @return A map <key, vaule>
+ * A method, which gets all plugins info (event those plugins which are
+ * disabled). It can be send via DBus to GUI and displayed to an user.
+ * Then a user can fill all needed informations like URLs etc.
+ * @return A vector of maps <key, vaule>
*/